componenttools
==============

.. automodule:: abjad.tools.componenttools

.. only:: html

   Abstract classes
   ----------------

   .. autosummary::

      ~abjad.tools.componenttools.Component.Component.Component
